#include "legenddialog.h"
#include "ui_legenddialog.h"

LegendDialog::LegendDialog(QWidget *parent) :
    QDialog(parent),
    ui(new Ui::LegendDialog)
{
    ui->setupUi(this);

#if defined(Q_WS_MAEMO_5)
    setAttribute(Qt::WA_Maemo5PortraitOrientation, true);
#endif
}

LegendDialog::~LegendDialog()
{
    delete ui;
}
